import secrets
import string

def random_passwd(length):
    lower = string.ascii_lowercase
    upper = string.ascii_uppercase
    num = string.digits
    symbols = string.punctuation
    all = lower + upper + num + symbols
    password = ''.join(secrets.choice(all) for i in range(length))  
    return password


import setuptools
from pathlib import Path

setuptools.setup(
    name="passwordgenerator_uz",
    description="Ushbu kutubxona yordamida parol generatsiya qilib olishingiz mumkin!",
    author="Ozodbek Sobirjonovich",
    author_email="ozodbeksobirjonovich@gmail.com",
    long_description=Path("README.md").read_text()
)